==> cloud-1.9.7.tar.gz: cloud-1.9.7/src/__init__.py <==
"""
Interface for cloud - the clientside module for PiCloud

Sample usage::

    import cloud
    jid = cloud.call(lambda: 3*3)
    >> Returns a job identifier
    cloud.result(jid)
    >> Returns 9

This will run the function lambda: 3*3 on PiCloud's
cluster, and return the result. Most functions, even
user-defined ones, can be passed through cloud.call

For cloud to work, you must first do one the following:

1. Have set api_key and api_secretkey in $HOME/.picloud/cloudconf.py
2. Call cloud.setkey( api_key=your_api_key, 
   api_secretkey=your_api_secretkey)
3. Set use_simulator to true in cloudconf.py or run cloud.start_simulator() 
   to use the cloud simulator, where cloud is run locally
"""
"""
Copyright (c) 2009 `PiCloud, Inc. <http://www.picloud.com>`_.  All rights reserved.

email: contact@picloud.com

The cloud package is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This package is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this package; if not, see 
http://www.gnu.org/licenses/lgpl-2.1.html    
"""

import sys
import imp

#versioning:
from .versioninfo import release_version
__version__ = release_version

#Input hooks
class ImportHook(object):
    def __init__(self):
        self.mods = []  #Reloading mods in order will reload entire cloud
    
    def load_module(self, fullname):
        """This is called by the system to load a module
            We use it to track mopdules after their code is loaded"""        
        parentmod, ext, submod = fullname.rpartition('.')
        if parentmod:
            path = sys.modules[parentmod].__path__
        else:
            path = ""
    
        file, filename, tuple = imp.find_module(submod, path)
        
        #This may load additional modules which are appended before this module in self.mods
        imp.acquire_lock()
        mod = imp.load_module(fullname, file, filename, tuple)
        imp.release_lock()  
        
        self.mods.append(fullname)
        
        return mod
    
    
    def find_module(self, fullname, path = None):
        """This is called by the system to find a module.
        cloud.* modules are hooked into our system"""
        
        if fullname.startswith('cloud') and 'server' not in fullname:
            self.path = path
            parentmod, ext, submod = fullname.rpartition('.')
            if parentmod:
                path = sys.modules[parentmod].__path__
            else:
                path = ""
            try: #Fails due to attempting relative import of python packages, e.g cloud.os
                grp = imp.find_module(submod, path)
                if not grp: #import error
                    return None
            except ImportError: 
                return None 
            else:
                return self
        else:
            return None
    
_modHook = ImportHook()    
sys.meta_path.append(_modHook) #registers our import hook    

from . import cloudconfig as cc
import cloudinterface
from . import cloud

__cloud = None
__type = None
__immutable = False

#function bindings
call = None
map = None
status = None
join = None
result = None
kill = None
is_simulated = None
running_on_cloud = None
connection_info = None

__all__ = ["call", "map", "status", "result", "iresult", "is_simulated", "join", "kill",
            "delete", "info", "connection_info", "running_on_cloud", "setkey", "finished_statuses",
             "start_simulator", "config", "getconfigpath", "iresult_unordered"]

c = """Should cloud simulator be used in lieu of a connection to a PiCloud server?
The Cloud Simulator simulates cloud.* functions locally, allowing for quicker debugging."""
__useSimulator =  cc.accountConfigurable('use_simulator',
                                          default=False,
                                          comment=c)

def _launch_cloud():
    cloudinterface._setcloud(sys.modules[__name__], 'simulated' if __useSimulator else 'network', restart=True)
    
_launch_cloud()

from .cloud import CloudException, CloudTimeoutError

def start_simulator(force_restart = False):
    """
    Simulate cloud functionality locally.
    If *force_restart* or not already in simulation mode, restart cloud and enter simulation.
    In simulation mode, the cloud will be run locally, on multiple processors, via 
    the multiprocessing library.
    Additional logging information by default will be enabled.
    For more information, see 
    `PiCloud documention <http://docs.picloud.com/client_adv.html#simulator>`_
    """
    

    cloudinterface._setcloud(sys.modules[__name__], 'simulated', restart=force_restart)

    
def setkey(api_key, api_secretkey, server_url=None, restart=False, immutable=False):
    """
    Connect cloud to your PiCloud account,
    Your *api_key* and *api_secretkey* are provided by PiCloud on the 
    `API Keys <http://www.picloud.com/accounts/apikeys/>`_ section of the PiCloud website.   
    
    *server_url* specifies the PiCloud server to connect to.  Leave this blank to have cloud auto-resolve servers.

    *restart* forces the cloud to reconnect
    
    This command will disable the simulator if it is running.
    """
    
    cloudinterface._setcloud(sys.modules[__name__], 'network', api_key, api_secretkey, server_url, restart, immutable)

def _getcloud():
    """Return internal cloud object. Only for internal use"""
    return __cloud

def getconfigpath():
    """
    Return the directory where PiCloud configuration and logging files are stored.    
    Configuration/logs are stored on a per-user basis
    """
    return _cc.fullconfigpath


#config:
if cc._needsWrite:
    from .util import writeconfig
    writeconfig.writeConfig()    

from .util.configmanager import ConfigSettings
config = ConfigSettings(cc.config)
del ConfigSettings
_cc = cc
del cc

try:
    from . import mp as mp
except ImportError:
    try:
        import multiprocessing
    except ImportError: #if mp error, fall back
        cloud.cloudLog.warn('Multiprocessing is not installed. Cloud.mp will be disabled')
    else:
        raise #something else has gone wrong
    
#cloud.account:
from . import account

from . import files

==> cloud-2.1.4.tar.gz: cloud-2.1.4/src/__init__.py <==
"""
Interface for cloud - the clientside module for PiCloud

Sample usage::

    import cloud
    jid = cloud.call(lambda: 3*3)
    >> Returns a job identifier
    cloud.result(jid)
    >> Returns 9

This will run the function lambda: 3*3 on PiCloud's
cluster, and return the result. Most functions, even
user-defined ones, can be passed through cloud.call

For cloud to work, you must first do one the following:

1. Have set api_key and api_secretkey in $HOME/.picloud/cloudconf.py
2. Call cloud.setkey( api_key=your_api_key, 
   api_secretkey=your_api_secretkey)
3. Set use_simulator to true in cloudconf.py or run cloud.start_simulator() 
   to use the cloud simulator, where cloud is run locally
"""
"""
Copyright (c) 2010 `PiCloud, Inc. <http://www.picloud.com>`_.  All rights reserved.

email: contact@picloud.com

The cloud package is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This package is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this package; if not, see 
http://www.gnu.org/licenses/lgpl-2.1.html    
"""

import sys
import imp

#versioning:
from .versioninfo import release_version
__version__ = release_version

#Input hooks
class ImportHook(object):
    def __init__(self):
        self.mods = []  #Reloading mods in order will reload entire cloud
    
    def load_module(self, fullname):
        """This is called by the system to load a module
            We use it to track mopdules after their code is loaded"""        
        parentmod, ext, submod = fullname.rpartition('.')
        if parentmod:
            path = sys.modules[parentmod].__path__
        else:
            path = ""
    
        file, filename, tuple = imp.find_module(submod, path)
        
        #This may load additional modules which are appended before this module in self.mods
        imp.acquire_lock()
        mod = imp.load_module(fullname, file, filename, tuple)
        imp.release_lock()  
        
        self.mods.append(fullname)
        
        return mod
    
    
    def find_module(self, fullname, path = None):
        """This is called by the system to find a module.
        cloud.* modules are hooked into our system"""
        
        if fullname.startswith('cloud') and 'server' not in fullname:
            self.path = path
            parentmod, ext, submod = fullname.rpartition('.')
            if parentmod:
                path = sys.modules[parentmod].__path__
            else:
                path = ""
            try: #Fails due to attempting relative import of python packages, e.g cloud.os
                grp = imp.find_module(submod, path)
                if not grp: #import error
                    return None
            except ImportError: 
                return None 
            else:
                return self
        else:
            return None
    
_modHook = ImportHook()    
sys.meta_path.append(_modHook) #registers our import hook    

from . import cloudconfig as cc
import cloudinterface
from . import cloud

__cloud = None
__type = None
__immutable = False

#function bindings
call = None
map = None
status = None
join = None
result = None
kill = None
is_simulated = None
running_on_cloud = None
connection_info = None

__all__ = ["call", "map", "status", "result", "iresult", "is_simulated", "join", "kill",
            "delete", "info", "connection_info", "running_on_cloud", "setkey", "finished_statuses",
             "start_simulator", "config", "getconfigpath"]

c = """Should cloud simulator be used in lieu of a connection to a PiCloud server?
The Cloud Simulator simulates cloud.* functions locally, allowing for quicker debugging."""
__useSimulator =  cc.accountConfigurable('use_simulator',
                                          default=False,
                                          comment=c)

def _launch_cloud():
    cloudinterface._setcloud(sys.modules[__name__], 'simulated' if __useSimulator else 'network', restart=True)
    
_launch_cloud()

from .cloud import CloudException, CloudTimeoutError

def start_simulator(force_restart = False):
    """
    Simulate cloud functionality locally.
    If *force_restart* or not already in simulation mode, restart cloud and enter simulation.
    In simulation mode, the cloud will be run locally, on multiple processors, via 
    the multiprocessing library.
    Additional logging information by default will be enabled.
    For more information, see 
    `PiCloud documention <http://docs.picloud.com/client_adv.html#simulator>`_
    """
    

    cloudinterface._setcloud(sys.modules[__name__], 'simulated', restart=force_restart)

    
def setkey(api_key, api_secretkey, server_url=None, restart=False, immutable=False):
    """
    Connect cloud to your PiCloud account,
    Your *api_key* and *api_secretkey* are provided by PiCloud on the 
    `API Keys <http://www.picloud.com/accounts/apikeys/>`_ section of the PiCloud website.   
    
    *server_url* specifies the PiCloud server to connect to.  Leave this blank to have cloud auto-resolve servers.

    *restart* forces the cloud to reconnect
    
    This command will disable the simulator if it is running.
    """
    
    cloudinterface._setcloud(sys.modules[__name__], 'network', api_key, api_secretkey, server_url, restart, immutable)

def _getcloud():
    """Return internal cloud object. Only for internal use"""
    return __cloud

def getconfigpath():
    """
    Return the directory where PiCloud configuration and logging files are stored.    
    Configuration/logs are stored on a per-user basis
    """
    return _cc.fullconfigpath

"""Read/Write configuration file"""
from .util.configmanager import ConfigSettings
config = ConfigSettings(cc.config)  #sets cc.config values
if cc._needsWrite:
    cc.flushConfig()
    cc._needsWrite = False    

del ConfigSettings
_cc = cc
del cc

try:
    from . import mp as mp
except ImportError:
    try:
        import multiprocessing
    except ImportError: #if mp error, fall back
        cloud.cloudLog.warn('Multiprocessing is not installed. Cloud.mp will be disabled')
    else:
        raise #something else has gone wrong
    
from . import account   #cloud.account
from . import cron      #cloud.cron
from . import files     #cloud.files
